package com.nisum.webfluxday2.controller;

import com.nisum.webfluxday2.model.Product;
import com.nisum.webfluxday2.service.ProductService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.web.bind.annotation.*;
import reactor.core.publisher.Flux;
import reactor.core.publisher.Mono;

@RestController
@CrossOrigin(origins = "*")
@RequestMapping("/api")
public class ProductController {

    @Autowired
    ProductService productService;

    @GetMapping("/products")
    @ResponseStatus(HttpStatus.OK)
    public Flux<Product> getAllProducts(){
        return productService.getAll();
    }

    @GetMapping("/products/{id}")
    @ResponseStatus(HttpStatus.OK)
    public Mono<Product> findProduct(@PathVariable String id){
        return productService.findProduct(id);
    }

    @PostMapping("/products")
    @ResponseStatus(HttpStatus.OK)
    public Mono<Product> addNewProduct(@RequestBody Product product){
        return productService.addProduct(product);
    }

    @PutMapping("/products/{id}")
    @ResponseStatus(HttpStatus.OK)
    public Mono<Product> alterProduct(@PathVariable String id, @RequestBody Product product){
        return productService.alterProduct(id, product);
    }

    @DeleteMapping("/products/{id}")
    @ResponseStatus(HttpStatus.OK)
    public void deleteProduct(@PathVariable String id){
        productService.deleteProduct(id).subscribe();
    }


}
